
=encoding utf8

=head1 名前

virt-df - Display free space on virtual filesystems

=head1 SYNOPSIS

 virt-df [--options]

 virt-df [--options] domname

 virt-df [--options] disk.img [disk.img ...]

=head1 DESCRIPTION

C<virt-df> is a command line tool to display free space on virtual machine
filesystems.  Unlike other tools, it doesn't just display the amount of
space allocated to a virtual machine, but can look inside the virtual
machine to see how much space is really being used.

It is like the L<df(1)> command, but for virtual machines, except that it
also works for Windows virtual machines.

If used without any arguments, C<virt-df> checks with libvirt to get a list
of all active and inactive guests, and performs a C<df>-type operation on
each one in turn, printing out the results.

If used with any argument(s), C<virt-df> performs a C<df>-type operation on
either the single named libvirt domain, or on the disk image(s) listed on
the command line (which must all belong to a single VM).  In this mode (with
arguments), C<virt-df> will I<only work for a single guest>.  If you want to
run on multiple guests, then you have to invoke C<virt-df> multiple times.

Use the C<--csv> option to get a format which can be easily parsed by other
programs.  Other options are mostly similar to standard C<df> options.  See
below for the complete list.

=head1 OPTIONS

=over 4

=item B<--help>

Display brief help.

=item B<--version>

Display version number and exit.

=item B<--connect URI> | B<-c URI>

If using libvirt, connect to the given I<URI>.  If omitted, then we connect
to the default libvirt hypervisor.

If you specify guest block devices directly, then libvirt is not used at
all.

=item B<--csv>

Write out the results in CSV format (comma-separated values).  This format
can be imported easily into databases and spreadsheets, but read L</NOTE
ABOUT CSV FORMAT> below.

=item B<--format> raw

Specify the format of disk images given on the command line.  If this is
omitted then the format is autodetected from the content of the disk image.

If disk images are requested from libvirt, then this program asks libvirt
for this information.  In this case, the value of the format parameter is
ignored.

If working with untrusted raw-format guest disk images, you should ensure
the format is always specified.

=item B<--human-readable> | B<-h>

Print sizes in human-readable format.

You are not allowed to use I<-h> and I<--csv> at the same time.

=item B<--inodes> | B<-i>

Print inodes instead of blocks.

=item B<--one-per-guest>

Run one libguestfs appliance per guest.  Normally C<virt-df> will add the
disks from several guests to a single libguestfs appliance.

You might use this option in the following circumstances:

=over 4

=item *

If you think an untrusted guest might actively try to exploit the libguestfs
appliance kernel, then this prevents one guest from interfering with the
stats printed for another guest.

=item *

If the kernel has a bug which stops it from accessing a filesystem in one
guest (see for example RHBZ#635373) then this allows libguestfs to continue
and report stats for further guests.

=back

=item B<--uuid>

Print UUIDs instead of names.  This is useful for following a guest even
when the guest is migrated or renamed, or when two guests happen to have the
same name.

Note that only domains that we fetch from libvirt come with UUIDs.  For disk
images, we still print the disk image name even when this option is
specified.

=back

=head1 NOTE ABOUT CSV FORMAT

Comma-separated values (CSV) is a deceptive format.  It I<seems> like it
should be easy to parse, but it is definitely not easy to parse.

Myth: Just split fields at commas.  Reality: This does I<not> work
reliably.  This example has two columns:

 "foo,bar",baz

Myth: Read the file one line at a time.  Reality: This does I<not> work
reliably.  This example has one row:

 "foo
 bar",baz

For shell scripts, use C<csvtool> (L<http://merjis.com/developers/csv> also
packaged in major Linux distributions).

For other languages, use a CSV processing library (eg. C<Text::CSV> for Perl
or Python's built-in csv library).

Most spreadsheets and databases can import CSV directly.

=head1 SHELL QUOTING

Libvirt guest names can contain arbitrary characters, some of which have
meaning to the shell such as C<#> and space.  You may need to quote or
escape these characters on the command line.  See the shell manual page
L<sh(1)> for details.

=head1 SEE ALSO

L<guestfs(3)>, L<guestfish(1)>, L<Sys::Guestfs(3)>, L<Sys::Guestfs::Lib(3)>,
L<Sys::Virt(3)>, L<http://libguestfs.org/>.

=head1 AUTHOR

Richard W.M. Jones L<http://people.redhat.com/~rjones/>

=head1 COPYRIGHT

Copyright (C) 2009-2010 Red Hat Inc.

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your option)
any later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 675 Mass
Ave, Cambridge, MA 02139, USA.

